@@ -2,8 +2,9 @@ import argparse
 import glob
 from os import path
 import os
+import subprocess
 import sys
-from typing import List, Tuple, Optional
+from typing import List, Optional, Tuple
 
 from . import __version__
 from .utils.analyzer import Analyzer
@@ -130,7 +131,24 @@ class SCAUI:
 
         return True, None
 
+    def _has_java(self) -> bool:
+        try:
+            subprocess.run(
+                "java --version", shell=True, check=True, capture_output=True
+            )
+        except subprocess.CalledProcessError:
+            return False
+        return True
+
     def run_analyzer(self) -> SCAProcedureResult:
+        if not self._has_java():
+            return (
+                False,
+                "Error: Java is unavailable.\n\n1. To install it, visit"
+                " https://www.java.com/en/download.\n2. After installing, make"
+                " sure you can access it in the cmd window by typing in `java"
+                " --version`.",
+            )
         if not self.ifile_list:
             return False, "Input files are not provided."
         analyzer = Analyzer(self.dir_stanford_parser, self.dir_stanford_tregex)
